@@ -729,21 +729,25 @@ sub entryNameSet{
 		return undef;
 	}
 
-	#makes sure the entry name is valid
+	#generate a entry name if one has not been
 	my $ehelper=Toader::Entry::Helper->new( $self->{toader} ) ;
+	if (!defined($entryName)) {
+		$entryName=$ehelper->generateEntryName;
+	}
+
+	#makes sure the entry name is valid
 	my $returned=$ehelper->validEntryName($entryName);
 	if ( ! $returned ) {
 		$self->{error}=9;
-		$self->{errorString}='Not a valid entry name';
+		if ( defined( $entryName ) ){
+			$self->{errorString}='"'.$entryName.'" is not a valid entry name';
+		}else{
+			$self->{errorString}='undef is not a valid entry name';
+		}
 		$self->warn;
 		return undef;
 	}
 
-	#generate a entry name if one has not been
-	if (!defined($entryName)) {
-		$entryName=$ehelper->generateEntryName;
-	}
-
 	$self->{entryName}=$entryName;
 
 	return 1;
