@@ -11,11 +11,11 @@ Toader::Render::Directory::Cleanup - This is used for cleaning up the output dir
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -27,7 +27,7 @@ This initiates the object.
 
 One argument is required and it is a L<Toader> object.
 
-	my $foo=Toader::Render::Directory::Cleanup->new($toader);
+    my $foo=Toader::Render::Directory::Cleanup->new($toader);
     if($foo->error){
         warn('error: '.$foo->error.":".$foo->errorString);
     }
@@ -41,6 +41,21 @@ sub new{
 			  error=>undef,
 			  errorString=>'',
 			  perror=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noToaderObj',
+					  2=>'notAtoaderObj',
+					  3=>'toaderPerror',
+					  4=>'notAdirectoryObj',
+					  5=>'noObj',
+					  6=>'noOutputDirSet',
+					  7=>'outputDirDoesNotExist',
+					  8=>'objPerror',
+					  9=>'noDirSet',
+					  10=>'pathhelperErrored',
+					  11=>'cleanupFailed',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -351,47 +366,49 @@ sub cleanup{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noToaderObj
 
 No L<Toader> object passed.
 
-=head2 2
+=head2 2, notAtoaderObj
 
 The passed object is not a L<Toader> object.
 
-=head2 3
+=head2 3, toaderPerror
 
 The L<Toader> object passed has a permanent error set.
 
-=head2 4
+=head2 4, notAdirectoryObj
 
 The passed object is not a L<Toader::Directory> object.
 
-=head2 5
+=head2 5, noObj
 
 No object passed.
 
-=head2 6
+=head2 6, noOutputDirSet
 
 The L<Toader> object has not had a output directory set.
 
-=head2 7
+=head2 7, outputDirDoesNotExist
 
 The output directory does not appear to exist or is not a directory.
 
-=head2 8
+=head2 8, objPerror
 
 The object has a permanent error set.
 
-=head2 9
+=head2 9, noDirSet
 
 The object has not had a directory set for it.
 
-=head2 10
+=head2 10, pathhelperErrored
 
 L<Toader::pathHelper> errored.
 
-=head2 11
+=head2 11, cleanupFailed
+
+Failed to cleanup up the old rendered object.
 
 =head1 AUTHOR
 
@@ -440,7 +457,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011. Zane C. Bowers-Hadley.
+Copyright 2013. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
