@@ -678,6 +678,123 @@ sub render{
 	return 1;
 }
 
+=head2 tags
+
+This renders the '.entries/tags.html' file.
+
+=cut
+
+sub tags{
+	my $self=$_[0];
+	
+	if ( ! $self->errorblank ){
+		return undef;
+	}
+
+	#makes sure we have a output directory set...
+	#while we don't care about this for rendering the content, we do need to
+	#know this for actually fully rendering it
+	my $output=$self->{toader}->getOutputDir;
+	if ( ! defined( $output ) ){
+		$self->{error}=11;
+		$self->{errorString}='No output directory has been set for the Toader object';
+		$self->warn;
+		return undef;
+	}
+
+	#makes sure the output directory exists
+	if ( ! -d $output ){
+		$self->{error}=12;
+		$self->{errorString}='The output directory, "'.$output.'", does not exist';
+		$self->warn;
+		return undef;
+	}
+
+	#this renders the content of it
+	my $content=$self->tagsContent;
+	if ( $self->error ){
+		$self->warnString('Failed to render the content to include');
+		return undef;
+	}
+
+    my $page=$self->{t}->fill_in( 'page',
+                                     {
+                                         toader=>\$self->{toader},
+										 g=>\$self->{g},
+										 self=>\$self,
+										 obj=>\$self->{obj},
+										 c=>\$self->{toader}->getConfig,
+										 locationID=>'Entry Tags',
+										 content=>$content,
+                                     });
+    if ( $self->{t}->error ){
+        $self->{error}=8;
+        $self->{errorString}='Filling in the template failed. error="'.
+            $self->{t}->error.'" errorString="'.$self->{t}->errorString.'"';
+        $self->warn;
+        return undef;
+    }
+
+	#the paths that will be used
+	my $dir=$output.'/'.$self->{r2r}.'/.entries/';
+	my $index=$dir.'tags.html';
+
+	#make sure the files and entry directory exist
+	if ( ! -d $dir ){
+		if ( ! make_path( $dir ) ){
+			$self->{error}=13;
+			$self->{errorString}='The output entry directry, "'.$dir.'", could not be created';
+			$self->warn;
+			return undef;
+		}
+	}
+
+	#write the index out
+	my $fh;
+	if ( ! open( $fh, '>', $index ) ){
+		$self->{error}=15;
+		$self->{errorString}='Failed to open the index, "'.$index.'", for writing';
+		$self->warn;
+		return undef;
+	}
+	print $fh $page;
+	close( $fh );
+
+	return 1;
+}
+
+=head2 tagsContent
+
+This renders the content for the index.html page for the entries.
+
+=cut
+
+sub tagsContent{
+	my $self=$_[0];
+	
+	if ( ! $self->errorblank ){
+		return undef;
+	}
+
+    my $content=$self->{t}->fill_in( 'entryTags',
+                                     {
+                                         toader=>\$self->{toader},
+										 g=>\$self->{g},
+										 self=>\$self,
+										 obj=>\$self->{obj},
+										 c=>\$self->{toader}->getConfig,
+                                     });
+    if ( $self->{t}->error ){
+        $self->{error}=8;
+        $self->{errorString}='Filling in the template failed. error="'.
+            $self->{t}->error.'" errorString="'.$self->{t}->errorString.'"';
+        $self->warn;
+        return undef;
+    }
+
+	return $content;
+}
+
 =head1 ERROR CODES
 
 =head2 1, noObj
