@@ -16,11 +16,11 @@ Toader::Render::Page - This renders a Toader::Page object.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.1
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.1';
 
 =head1 SYNOPSIS
 
@@ -67,6 +67,23 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  toDir=>'../../',
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'noToaderObj',
+					  3=>'objPerror',
+					  4=>'toaderPerror',
+					  5=>'noDirSet',
+					  6=>'cleanupInitErrored',
+					  7=>'cleanupErrored',
+					  8=>'backendInitErrored',
+					  9=>'pathhelperInitErrored',
+					  11=>'noOutputDirSet',
+					  12=>'outputDirDoesNotExist',
+					  13=>'outputPageDirCreationFailed',
+					  14=>'outputFileDirCreationFailed',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -136,9 +153,13 @@ sub new{
 		$self->warn;
 		return $self;
 	}
+	$self->{dir}=$self->{obj}->dirGet;
 
 	#initialize this here for simplicity
-	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet });
+	$self->{t}=Toader::Templates->new({ 
+		dir=>$self->{obj}->dirGet,
+		toader=>$args{toader},
+									  });
 
 	#initialize the general object here for simplicity
 	$self->{g}=Toader::Render::General->new(
@@ -153,16 +174,6 @@ sub new{
 		$self->{perror}='';
 	}
 
-	#make sure the renderable object has a directory set
-	$self->{dir}=$self->{obj}->dirGet;
-	if ( ! defined( $self->{dir} ) ){
-		$self->{perror}=1;
-		$self->{error}=10;
-		$self->{errorString}='The renderable object does not have a directory specified';
-		$self->warn;
-		return $self;
-	}
-
 	#initialize the Toader::pathHelper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
 	if ( $self->{ph}->error ){
@@ -548,59 +559,55 @@ sub summaryContent{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No L<Toader::Page> object specified.
 
-=head2 2
+=head2 2,  noToaderObj
 
 No L<Toader> object specified.
 
-=head2 3
+=head2 3, objPerror
 
 The L<Toader::Page> object has a permanent error set.
 
-=head2 4
+=head2 4, toaderPerror
 
 The L<Toader> object has a permanent error set.
 
-=head2 5
+=head2 5, noDirSet
 
 The L<Toader::Page> object does not have a directory set
 
-=head2 6
+=head2 6, cleanupInitErrored
 
 Failed to initialize the cleanup module.
 
-=head2 7
+=head2 7, cleanupErrored
 
 Failed to cleanup.
 
-=head2 8
+=head2 8, backendInitErrored
 
 Failed to initialize the backend.
 
-=head2 9
+=head2 9, pathhelperInitErrored
 
 Failed to initialize the path helper.
 
-=head2 10
-
-The object does not have a directory set.
-
-=head2 11
+=head2 11, noOutputDirSet
 
 The L<Toader> object does not have a output directory set.
 
-=head2 12
+=head2 12, outputDirDoesNotExist
 
 The output directory does not exist.
 
-=head2 13
+=head2 13, outputPageDirCreationFailed
 
 The output page directory could not be created.
 
-=head2 14
+=head2 14, outputFileDirCreationFailed
 
 The output file directory could not be created.
 
@@ -652,7 +659,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011. Zane C. Bowers-Hadley.
+Copyright 2013. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
