@@ -10,11 +10,11 @@ Toader::isaToaderDir - Checks if a directory has Toader support or not.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 
 =head1 SYNOPSIS
@@ -47,6 +47,12 @@ sub new{
 			  error=>undef,
 			  errorString=>'',
 			  perror=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noDirSpecified',
+					  2=>'notAdir',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -106,11 +112,11 @@ sub isaToaderDir{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noDirSpecified
 
 No directory specified.
 
-=head2 2
+=head2 2, notAdir
 
 Not a directory.
 
@@ -162,7 +168,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Zane C. Bowers-Hadley.
+Copyright 2013 Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -173,4 +179,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Toader
+1; # End of Toader::isaToaderDir
