@@ -14,11 +14,11 @@ Toader::pathHelper - Various path related helpers.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -49,6 +49,15 @@ sub new{
 			  errorString=>'',
 			  isatd=>Toader::isaToaderDir->new,
 			  perror=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noDirSpecified',
+					  2=>'notAtoaderDir',
+					  3=>'otherToaderDir',
+					  4=>'notAbleToFindRoot',
+					  5=>'notUnderToaderRoot',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -417,24 +426,24 @@ sub underRootNT{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noDirSpecified
 
 No directory specified.
 
-=head2 2
+=head2 2, notAtoaderDir
 
 The directory is not a L<Toader> directory.
 
-=head2 3
+=head2 3, otherToaderDir
 
 The L<Toader> directory in question is not under the L<Toader>
 directory root it was initialized with.
 
-=head2 4
+=head2 4, notAbleToFindRoot
 
-Unable to find the root.
+Unable to find the root L<Toader> directory.
 
-=head2 5
+=head2 5, notUnderToaderRoot
 
 The directory is not under the root L<Toader> directory.
 
